#Flask
from flask import Flask, jsonify
from flask_cors import CORS
app = Flask(__name__)
from flask_socketio import SocketIO
CORS(app)
socketio = SocketIO(app)

#Buitentemperatuur
from Onewire import Ds1820
tempBuiten = Ds1820()

#Binnentemperatuur en luchtvochtigheid
import Adafruit_DHT
humidity, temperature = Adafruit_DHT.read_retry(11, 17)

#Database
from database import Database
endpoint = '/api/v1'
conn = Database(app, 'mct', 'mct', 'project1_venti2', '169.254.10.1')

#Threading
import threading

#Ventilatoren
import l293d
motor1 = l293d.DC(22, 18, 16)
motor2 = l293d.DC(12, 13, 15)
global temperatuur

#Lichtsensor
from Mcp import Mcp
lichtsensor = Mcp()
waarde_licht = lichtsensor.read_channel(1)

@app.route(endpoint + '/')
def hallo():
    return "Server is running"

@app.route(endpoint + '/sensor/<sensor>')
def sensor_detail(sensor):
    sensor = conn.get_data('SELECT sensor.Name, history.value from sensor LEFT JOIN history ON sensor.idSensor = history.idSensor where sensor.Name = %s ', sensor)
    return jsonify(sensor), 200

@socketio.on("connect")
def connecting():
    socketio.emit("connected") #bij verbinding wordt connected gestuurd
    print("Connection with client established")

def publishTemp():
    temperatuur = round(tempBuiten.temperature, 0)
    if temperatuur != 0:
        DBtemp_buiten = conn.set_data('INSERT INTO history(value, idSensor) VALUES (%s, %s)', (temperatuur, 1))
    print(temperatuur)
    socketio.emit("buitentemperatuur", temperatuur)
    threading.Timer(60, publishTemp).start()

@socketio.on("buitentemp")
def data_in_db():
    publishTemp()

def publishTempHum():
    print(temperature)
    temperatuur = round(temperature)
    if temperatuur != 0:
        DBtemp_binnen = conn.set_data('INSERT INTO history(value, idSensor) VALUES(%s, %s)', (temperatuur, 3))
    print(temperatuur)
    socketio.emit("binnentemperatuur", temperatuur)
    luchtvochtigheid = round(humidity)
    if luchtvochtigheid != 0:
        DBhumidity = conn.set_data('INSERT INTO history(value, idSensor) VALUES(%s, %s)', (luchtvochtigheid, 4))
    print(luchtvochtigheid)
    socketio.emit("luchtvochtigheid", humidity)

    threading.Timer(60, publishTempHum).start()
    ventilatoren()

@socketio.on("binnentemp_vochtigheid")
def binnen_vochtig():
    publishTempHum()

def publishLightValue():
    print(waarde_licht)
    procent_licht = waarde_licht/1023*100
    print("Licht: {0}".format(procent_licht))
    if procent_licht != 0:
        DBlicht = conn.set_data('INSERT INTO history(value, idSensor) VALUES(%s, %s)',(waarde_licht, 2))
    socketio.emit("lichtsensor", procent_licht)

    threading.Timer(60, publishLightValue).start()

@socketio.on("lichtsensor")
def licht_sensor():
    publishLightValue()


@socketio.on("inputBinnen")
def input_binnen(waarde):
    print("Waarde: " + str(waarde))
    actie = "input binnentemperatuur"
    beschrijving = "gebruiker verandert gewenste temperatuur"
    nieuwe_binnen = conn.set_data('INSERT INTO action(Action, Description, idHistory, idSensor) VALUES (%s,%s,%s,%s)', (actie, beschrijving, "NULL","NULL"))
    if temperature > nieuwe_binnen:
        motor1.clockwise(20)
        print("{0} hoger dan {1}".format(temperature, nieuwe_binnen))

@socketio.on("aangepasteTemp")
def aangepaste_temp(waarde):
    threading.Timer(20,aangepaste_temp).start()
    if temperature > int(waarde):
        motor1.clockwise(20)
        print("{0} hoger dan gewenste {1}".format(temperature, waarde))
def ventilatoren():
    threading.Timer(20, ventilatoren).start()
    if temperature > 20:
        motor1.clockwise(20)
        print("Temperatuur hoger dan 20")
    elif humidity > 50:
        motor2.anticlockwise(20)
        print("Luchtvochtigheid hoger dan 50")
    else:
        motor1.stop()
        motor2.stop()



if __name__ == '__main__':
    socketio.run(app, host='0.0.0.0', port=5000)